.. _TransformersDocs:
btrdb.transformers
=========================

A number of transformation and serialization functions have been developed so
you can use the data in the format of your choice.  These functions are provided
in the :code:`StreamSet` class.

.. automodule:: btrdb.transformers

.. autofunction:: arrow_to_dict

.. autofunction:: arrow_to_numpy

.. autofunction:: arrow_to_series

.. autofunction:: arrow_to_dataframe

.. autofunction:: arrow_to_polars

.. autofunction:: arrow_to_arrow_table

.. autofunction:: to_dict

.. autofunction:: to_array

.. autofunction:: to_polars

.. autofunction:: to_series

.. autofunction:: to_dataframe

.. autofunction:: to_csv
